==> v1.0.4.zip: woodpecker/README.md <==
<p align="center">
  <a href="https://github.com/woodpecker-ci/woodpecker/">
    <img alt="Woodpecker" src="docs/static/img/logo.svg" width="220"/>
  </a>
</p>
<br/>
<p align="center">
  <a href="https://ci.woodpecker-ci.org/woodpecker-ci/woodpecker" title="Build Status">
    <img src="https://ci.woodpecker-ci.org/api/badges/woodpecker-ci/woodpecker/status.svg">
  </a>
  <a href="https://codecov.io/gh/woodpecker-ci/woodpecker">
    <img src="https://codecov.io/gh/woodpecker-ci/woodpecker/branch/master/graph/badge.svg"/>
  </a>
  <a href="https://translate.woodpecker-ci.org/engage/woodpecker-ci/">
    <img src="https://translate.woodpecker-ci.org/widgets/woodpecker-ci/-/ui/svg-badge.svg" alt="Translation status" />
  </a>
  <a href="https://discord.gg/fcMQqSMXJy" title="Join the Discord chat at https://discord.gg/fcMQqSMXJy">
    <img src="https://img.shields.io/discord/838698813463724034.svg?label=discord">
  </a>
  <a href="https://matrix.to/#/#woodpecker:matrix.org" title="Join the Matrix space at https://matrix.to/#/#woodpecker:matrix.org">
    <img src="https://img.shields.io/matrix/woodpecker:matrix.org?label=matrix">
  </a>
  <a href="https://goreportcard.com/badge/github.com/woodpecker-ci/woodpecker" title="Go Report Card">
    <img src="https://goreportcard.com/badge/github.com/woodpecker-ci/woodpecker">
  </a>
  <a href="https://godoc.org/github.com/woodpecker-ci/woodpecker" title="GoDoc">
    <img src="https://godoc.org/github.com/woodpecker-ci/woodpecker?status.svg">
  </a>
  <a href="https://github.com/woodpecker-ci/woodpecker/releases/latest" title="GitHub release">
    <img src="https://img.shields.io/github/v/release/woodpecker-ci/woodpecker?sort=semver">
  </a>
  <a href="https://hub.docker.com/r/woodpeckerci/woodpecker-server" title="Docker pulls">
    <img src="https://img.shields.io/docker/pulls/woodpeckerci/woodpecker-server">
  </a>
  <a href="https://opensource.org/licenses/Apache-2.0" title="License: Apache-2.0">
    <img src="https://img.shields.io/badge/License-Apache%202.0-blue.svg">
  </a>
  <a href="https://bestpractices.coreinfrastructure.org/projects/5309">
    <img src="https://bestpractices.coreinfrastructure.org/projects/5309/badge">
  </a>
  <a href="https://www.tickgit.com/browse?repo=github.com/woodpecker-ci/woodpecker" title="TODOs">
    <img src="https://badgen.net/https/api.tickgit.com/badgen/github.com/woodpecker-ci/woodpecker">
  </a>
</p>
<br/>

# Woodpecker

> Woodpecker is a community fork of the Drone CI system.

![woodpecker](docs/docs/woodpecker.png)

## 🫶 Support

Please consider to donate and become a backer. 🙏 [[Become a backer](https://opencollective.com/woodpecker-ci#category-CONTRIBUTE)]

<a href="https://opencollective.com/woodpecker-ci" target="_blank"><img src="https://opencollective.com/woodpecker-ci/backers.svg?width=890"></a>

## 🚀 Usage

### .woodpecker.yml

- Place your pipeline in a file named `.woodpecker.yml` in your repository
- Pipeline steps can be named as you like
- Run any command in the commands section

[Read More](https://woodpecker-ci.org/docs/usage/intro)

### Build steps are containers

- Define any Docker image as context
- Install the needed tools in custom Docker images, use them as context

[Read More](https://woodpecker-ci.org/docs/usage/pipeline-syntax#steps)

### Plugins

Woodpecker has [official plugins](https://woodpecker-ci.org/plugins), but you can also use your own.

[Read More](https://woodpecker-ci.org/docs/usage/plugins/plugins)

## 📖 Documentation

https://woodpecker-ci.org/

## ✨ Contribute

See [Contributing Guide](CONTRIBUTING.md)

[![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://woodpecker-ci.org/docs/next/development/getting-started#gitpod)

## 📣 Translate

We use an own [Weblate](https://weblate.org/en/) instance at [translate.woodpecker-ci.org](https://translate.woodpecker-ci.org).

<a href="https://translate.woodpecker-ci.org/engage/woodpecker-ci/">
  <img src="https://translate.woodpecker-ci.org/widgets/woodpecker-ci/-/ui/multi-blue.svg" alt="Translation status" />
</a>

## 👋 Who uses Woodpecker?

[Codeberg](https://codeberg.org), the Woodpecker project itself, and many others.

Leave a [comment](https://github.com/woodpecker-ci/woodpecker/issues/122) if you're using it as well.

Also consider using the topic `WoodpeckerCI` in your repository, so others can learn from your config and use the hashtag `#WoodpeckerCI` when talking about the project on social media!

Here are some places where people mention Woodpecker:

- [GitHub](https://github.com/topics/WoodpeckerCI)
- [Codeberg](https://codeberg.org/explore/repos?q=woodpeckerci&topic=1)
- [Twitter](https://twitter.com/search?q=%23WoodpeckerCI&src=typed_query)
- [Fediverse](https://mastodon.social/tags/WoodpeckerCI)

## ✨ Stars over time

[![Stargazers over time](https://starchart.cc/woodpecker-ci/woodpecker.svg)](https://starchart.cc/woodpecker-ci/woodpecker)

## License

Woodpecker is Apache 2.0 licensed with the source files in this repository having a header indicating which license they are under and what copyrights apply.

Files under the `docs/` folder are licensed under Creative Commons Attribution-ShareAlike 4.0 International Public License.

==> v2.0.0-rc.0.zip: woodpecker/README.md <==
# Woodpecker

<p align="center">
  <a href="https://github.com/woodpecker-ci/woodpecker/">
    <img alt="Woodpecker" src="docs/static/img/logo.svg" width="220"/>
  </a>
</p>
<br/>
<p align="center">
  <a href="https://ci.woodpecker-ci.org/woodpecker-ci/woodpecker" title="Build Status">
    <img src="https://ci.woodpecker-ci.org/api/badges/woodpecker-ci/woodpecker/status.svg">
  </a>
  <a href="https://codecov.io/gh/woodpecker-ci/woodpecker">
    <img src="https://codecov.io/gh/woodpecker-ci/woodpecker/branch/main/graph/badge.svg"/>
  </a>
  <a href="https://translate.woodpecker-ci.org/engage/woodpecker-ci/">
    <img src="https://translate.woodpecker-ci.org/widgets/woodpecker-ci/-/ui/svg-badge.svg" alt="Translation status" />
  </a>
  <a href="https://discord.gg/fcMQqSMXJy" title="Join the Discord chat at https://discord.gg/fcMQqSMXJy">
    <img src="https://img.shields.io/discord/838698813463724034.svg?label=discord">
  </a>
  <a href="https://matrix.to/#/#woodpecker:matrix.org" title="Join the Matrix space at https://matrix.to/#/#woodpecker:matrix.org">
    <img src="https://img.shields.io/matrix/woodpecker:matrix.org?label=matrix">
  </a>
  <a href="https://goreportcard.com/report/github.com/woodpecker-ci/woodpecker" title="Go Report Card">
    <img src="https://goreportcard.com/badge/github.com/woodpecker-ci/woodpecker">
  </a>
  <a href="https://godoc.org/github.com/woodpecker-ci/woodpecker" title="GoDoc">
    <img src="https://godoc.org/github.com/woodpecker-ci/woodpecker?status.svg">
  </a>
  <a href="https://github.com/woodpecker-ci/woodpecker/releases/latest" title="GitHub release">
    <img src="https://img.shields.io/github/v/release/woodpecker-ci/woodpecker?sort=semver">
  </a>
  <a href="https://hub.docker.com/r/woodpeckerci/woodpecker-server" title="Docker pulls">
    <img src="https://img.shields.io/docker/pulls/woodpeckerci/woodpecker-server">
  </a>
  <a href="https://opensource.org/licenses/Apache-2.0" title="License: Apache-2.0">
    <img src="https://img.shields.io/badge/License-Apache%202.0-blue.svg">
  </a>
  <a href="https://bestpractices.coreinfrastructure.org/projects/5309">
    <img src="https://bestpractices.coreinfrastructure.org/projects/5309/badge">
  </a>
  <a href="https://www.tickgit.com/browse?repo=github.com/woodpecker-ci/woodpecker" title="TODOs">
    <img src="https://badgen.net/https/api.tickgit.com/badgen/github.com/woodpecker-ci/woodpecker">
  </a>
  <a href="https://github.com/pre-commit/pre-commit" title="TODOs">
    <img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit">
  </a>
</p>
<br/>

Woodpecker is a community fork of the Drone CI system.

![woodpecker](docs/docs/woodpecker.png)

## 🫶 Support

Please consider to donate and become a backer. 🙏 [[Become a backer](https://opencollective.com/woodpecker-ci#category-CONTRIBUTE)]

<a href="https://opencollective.com/woodpecker-ci" target="_blank"><img src="https://opencollective.com/woodpecker-ci/backers.svg?width=890"></a>

## 📖 Documentation

<https://woodpecker-ci.org/>

## ✨ Contribute

See [Contributing Guide](CONTRIBUTING.md)

[![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://woodpecker-ci.org/docs/next/development/getting-started#gitpod)

## 📣 Translate

We use an own [Weblate](https://weblate.org/en/) instance at [translate.woodpecker-ci.org](https://translate.woodpecker-ci.org).

<a href="https://translate.woodpecker-ci.org/engage/woodpecker-ci/">
  <img src="https://translate.woodpecker-ci.org/widgets/woodpecker-ci/-/ui/multi-blue.svg" alt="Translation status" />
</a>

## 👋 Who uses Woodpecker?

Woodpecker is used by [itself](https://ci.woodpecker-ci.org/woodpecker/woodpecker-ci/) multiple well-known companies, organizations like [Codeberg](https://codeberg.org), hobbyist and many others.

Leave a [comment](https://github.com/woodpecker-ci/woodpecker/discussions/2149) if you're using it as well.

Also consider using the topic `WoodpeckerCI` in your repository, so others can learn from your config and use the hashtag `#WoodpeckerCI` when talking about the project on social media!

Here are some places where people mention Woodpecker:

- [GitHub](https://github.com/topics/WoodpeckerCI)
- [Codeberg](https://codeberg.org/explore/repos?q=woodpeckerci&topic=1)
- [Twitter](https://twitter.com/search?q=%23WoodpeckerCI&src=typed_query)
- [Fediverse](https://mastodon.social/tags/WoodpeckerCI)

## ✨ Stars over time

[![Stargazers over time](https://starchart.cc/woodpecker-ci/woodpecker.svg)](https://starchart.cc/woodpecker-ci/woodpecker)

## License

Woodpecker is Apache 2.0 licensed with the source files in this repository having a header indicating which license they are under and what copyrights apply.

Files under the `docs/` folder are licensed under Creative Commons Attribution-ShareAlike 4.0 International Public License.
